Learn R Programming

preferably (version 0.4.1)

preferably: preferably

Description

An accessible template for pkgdown websites with dynamic light/dark mode support

Arguments

Author

Amir Masoud Abdol (i@amirmasoudabdol.name)

Details

This is an accessible template for 'pkgdown'. It uses two bootstrap themes, Flatly and Darkly and utilizes the 'prefers-color-scheme' CSS variable to automatically serve either of the two based on users' operating system setting, or allowing them to manually toggle between them.

See Also