An accessible template for pkgdown websites with dynamic light/dark mode support
Amir Masoud Abdol (i@amirmasoudabdol.name)
This is an accessible template for 'pkgdown'. It uses two bootstrap themes, Flatly and Darkly and utilizes the 'prefers-color-scheme' CSS variable to automatically serve either of the two based on users' operating system setting, or allowing them to manually toggle between them.
Useful links: